@@ -23,31 +23,36 @@ The zone transfer request API now supports system scope and default roles.
 """
 
 deprecated_create_zone_transfer_request = policy.DeprecatedRule(
-        name="create_zone_transfer_request",
-        check_str=base.RULE_ADMIN_OR_OWNER
+    name="create_zone_transfer_request",
+    check_str=base.RULE_ADMIN_OR_OWNER,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.WALLABY
 )
 deprecated_get_zone_transfer_request = policy.DeprecatedRule(
     name="get_zone_transfer_request",
-    check_str=base.RULE_ZONE_TRANSFER
+    check_str=base.LEGACY_RULE_ZONE_TRANSFER,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.WALLABY
 )
 deprecated_get_zone_transfer_request_detailed = policy.DeprecatedRule(
     name="get_zone_transfer_request_detailed",
-    check_str=base.RULE_ADMIN_OR_OWNER
-)
-deprecated_find_zone_transfer_requests = policy.DeprecatedRule(
-    name="find_zone_transfer_requests",
-    check_str=base.RULE_ANY
+    check_str=base.RULE_ADMIN_OR_OWNER,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.WALLABY
 )
 deprecated_update_zone_transfer_request = policy.DeprecatedRule(
     name="update_zone_transfer_request",
-    check_str=base.RULE_ADMIN_OR_OWNER
+    check_str=base.RULE_ADMIN_OR_OWNER,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.WALLABY
 )
 deprecated_delete_zone_transfer_request = policy.DeprecatedRule(
     name="delete_zone_transfer_request",
-    check_str=base.RULE_ADMIN_OR_OWNER
+    check_str=base.RULE_ADMIN_OR_OWNER,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.WALLABY
 )
 
-
 rules = [
     policy.DocumentedRuleDefault(
         name="create_zone_transfer_request",
@@ -60,31 +65,26 @@ rules = [
                 'method': 'POST'
             }
         ],
-        deprecated_rule=deprecated_create_zone_transfer_request,
-        deprecated_reason=DEPRECATED_REASON,
-        deprecated_since=versionutils.deprecated.WALLABY
+        deprecated_rule=deprecated_create_zone_transfer_request
     ),
     policy.DocumentedRuleDefault(
         name="get_zone_transfer_request",
         check_str=base.RULE_ZONE_TRANSFER,
+        scope_types=['system', 'project'],
         description="Show a Zone Transfer Request",
         operations=[
             {
                 'path': '/v2/zones/tasks/transfer_requests/{zone_transfer_request_id}',  # noqa
                 'method': 'GET'
-            }, {
-                'path': '/v2/zones/tasks/transfer_requests/{zone_transfer_request_id}',  # noqa
-                'method': 'PATCH'
             }
-        ]
+        ],
+        deprecated_rule=deprecated_get_zone_transfer_request
     ),
     policy.RuleDefault(
         name="get_zone_transfer_request_detailed",
         check_str=base.SYSTEM_OR_PROJECT_READER,
         scope_types=['system', 'project'],
-        deprecated_rule=deprecated_create_zone_transfer_request,
-        deprecated_reason=DEPRECATED_REASON,
-        deprecated_since=versionutils.deprecated.WALLABY
+        deprecated_rule=deprecated_create_zone_transfer_request
     ),
     policy.DocumentedRuleDefault(
         name="find_zone_transfer_requests",
@@ -95,7 +95,7 @@ rules = [
                 'path': '/v2/zones/tasks/transfer_requests',
                 'method': 'GET'
             }
-        ]
+        ],
     ),
     policy.RuleDefault(
         name="find_zone_transfer_request",
@@ -112,9 +112,7 @@ rules = [
                 'method': 'PATCH'
             }
         ],
-        deprecated_rule=deprecated_update_zone_transfer_request,
-        deprecated_reason=DEPRECATED_REASON,
-        deprecated_since=versionutils.deprecated.WALLABY
+        deprecated_rule=deprecated_update_zone_transfer_request
     ),
     policy.DocumentedRuleDefault(
         name="delete_zone_transfer_request",
@@ -127,9 +125,7 @@ rules = [
                 'method': 'DELETE'
             }
         ],
-        deprecated_rule=deprecated_delete_zone_transfer_request,
-        deprecated_reason=DEPRECATED_REASON,
-        deprecated_since=versionutils.deprecated.WALLABY
+        deprecated_rule=deprecated_delete_zone_transfer_request
     )
 ]
 
