@@ -25,6 +25,7 @@ from designate import exceptions
 from designate.central import rpcapi as central_rpcapi
 from designate.context import DesignateContext
 from designate.objects import Record
+from designate.objects import RecordList
 from designate.objects import RecordSet
 from designate.plugin import ExtensionPlugin
 
@@ -64,30 +65,77 @@ class NotificationHandler(ExtensionPlugin):
         context = DesignateContext.get_admin_context(all_tenants=True)
         return self.central_api.get_zone(context, zone_id)
 
-    def _find_or_create_recordset(self, context, zone_id, name, type,
-                                  ttl=None):
+    def _create_or_update_recordset(self, context, records, zone_id, name,
+                                    type, ttl=None):
         name = name.encode('idna').decode('utf-8')
 
         try:
-            # Attempt to create an empty recordset
+            # Attempt to create a new recordset.
             values = {
                 'name': name,
                 'type': type,
                 'ttl': ttl,
             }
+            recordset = RecordSet(**values)
+            recordset.records = RecordList(objects=records)
+            recordset.validate()
             recordset = self.central_api.create_recordset(
-                context, zone_id, RecordSet(**values))
-
+                context, zone_id, recordset
+            )
         except exceptions.DuplicateRecordSet:
-            # Fetch the existing recordset
+            # Fetch and update the existing recordset.
             recordset = self.central_api.find_recordset(context, {
                 'zone_id': zone_id,
                 'name': name,
                 'type': type,
             })
-
+            for record in records:
+                recordset.records.append(record)
+            recordset.validate()
+            recordset = self.central_api.update_recordset(
+                context, recordset
+            )
+        LOG.debug('Creating record in %s / %s', zone_id, recordset['id'])
         return recordset
 
+    def _update_or_delete_recordset(self, context, zone_id, recordset_id,
+                                    record_to_delete):
+        LOG.debug(
+            'Deleting record in %s / %s',
+            zone_id, record_to_delete['id']
+        )
+        try:
+            recordset = self.central_api.get_recordset(
+                context, zone_id, recordset_id
+            )
+
+            # Record not longer in recordset. Lets abort.
+            if record_to_delete not in recordset.records:
+                LOG.debug(
+                    'Record %s not found in recordset %s',
+                    record_to_delete['id'], recordset_id
+                )
+                return
+
+            # Remove the record from the recordset.
+            recordset.records.remove(record_to_delete)
+
+            if not recordset.records:
+                # Recordset is now empty. Remove it.
+                self.central_api.delete_recordset(
+                    context, zone_id, recordset_id
+                )
+                return
+
+            # Recordset still has records, validate it and update it.
+            recordset.validate()
+            self.central_api.update_recordset(context, recordset)
+        except exceptions.RecordSetNotFound:
+            LOG.info(
+                'Recordset %s for record %s was already removed',
+                recordset_id, record_to_delete['id']
+            )
+
 
 class BaseAddressHandler(NotificationHandler):
     default_formatv4 = ('%(hostname)s.%(domain)s',)
@@ -125,8 +173,8 @@ class BaseAddressHandler(NotificationHandler):
             self.default_formatv6
         )
 
-    def _create(self, addresses, extra, zone_id, managed=True,
-                resource_type=None, resource_id=None):
+    def _create(self, addresses, extra, zone_id, resource_type=None,
+                resource_id=None):
         """
         Create a record from addresses
 
@@ -134,15 +182,9 @@ class BaseAddressHandler(NotificationHandler):
                           {'version': 4, 'ip': '10.0.0.1'}
         :param extra: Extra data to use when formatting the record
         :param zone_id: The ID of the designate zone.
-        :param managed: Is it a managed resource
         :param resource_type: The managed resource type
         :param resource_id: The managed resource ID
         """
-        if not managed:
-            LOG.warning(
-                'Deprecation notice: Unmanaged designate-sink records are '
-                'being deprecated please update the call '
-                'to remove managed=False')
         LOG.debug('Using Zone ID: %s', zone_id)
         zone = self.get_zone(zone_id)
         LOG.debug('Domain: %r', zone)
@@ -170,66 +212,45 @@ class BaseAddressHandler(NotificationHandler):
                     'name': fmt % event_data,
                     'type': 'A' if addr['version'] == 4 else 'AAAA'}
 
-                recordset = self._find_or_create_recordset(
-                    context, **recordset_values)
-
                 record_values = {
-                    'data': addr['address']}
+                    'data': addr['address'],
+                    'managed': True,
+                    'managed_plugin_name': self.get_plugin_name(),
+                    'managed_plugin_type': self.get_plugin_type(),
+                    'managed_resource_type': resource_type,
+                    'managed_resource_id': resource_id
+                }
+                self._create_or_update_recordset(
+                    context, [Record(**record_values)], **recordset_values
+                )
 
-                if managed:
-                    record_values.update({
-                        'managed': managed,
-                        'managed_plugin_name': self.get_plugin_name(),
-                        'managed_plugin_type': self.get_plugin_type(),
-                        'managed_resource_type': resource_type,
-                        'managed_resource_id': resource_id})
-
-                LOG.debug('Creating record in %s / %s with values %r',
-                          zone['id'], recordset['id'], record_values)
-                self.central_api.create_record(context,
-                                               zone['id'],
-                                               recordset['id'],
-                                               Record(**record_values))
-
-    def _delete(self, zone_id, managed=True, resource_id=None,
-                resource_type='instance', criterion=None):
+    def _delete(self, zone_id, resource_id=None, resource_type='instance',
+                criterion=None):
         """
         Handle a generic delete of a fixed ip within a zone
 
         :param zone_id: The ID of the designate zone.
-        :param managed: Is it a managed resource
         :param resource_id: The managed resource ID
         :param resource_type: The managed resource type
         :param criterion: Criterion to search and destroy records
         """
-        if not managed:
-            LOG.warning(
-                'Deprecation notice: Unmanaged designate-sink records are '
-                'being deprecated please update the call '
-                'to remove managed=False')
         criterion = criterion or {}
 
         context = DesignateContext().elevated()
         context.all_tenants = True
         context.edit_managed_records = True
 
-        criterion.update({'zone_id': zone_id})
-
-        if managed:
-            criterion.update({
-                'managed': managed,
-                'managed_plugin_name': self.get_plugin_name(),
-                'managed_plugin_type': self.get_plugin_type(),
-                'managed_resource_id': resource_id,
-                'managed_resource_type': resource_type
-            })
+        criterion.update({
+            'zone_id': zone_id,
+            'managed': True,
+            'managed_plugin_name': self.get_plugin_name(),
+            'managed_plugin_type': self.get_plugin_type(),
+            'managed_resource_id': resource_id,
+            'managed_resource_type': resource_type
+        })
 
         records = self.central_api.find_records(context, criterion)
-
         for record in records:
-            LOG.debug('Deleting record %s', record['id'])
-
-            self.central_api.delete_record(context,
-                                           zone_id,
-                                           record['recordset_id'],
-                                           record['id'])
+            self._update_or_delete_recordset(
+                context, zone_id, record['recordset_id'], record
+            )
