@@ -11,13 +11,12 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from oslo_log import log as logging
 
-from designate.objects.adapters.api_v2 import base
-from designate import objects
-from designate import policy
+from designate.common import constants
 from designate import exceptions
-LOG = logging.getLogger(__name__)
+from designate import objects
+from designate.objects.adapters.api_v2 import base
+from designate import policy
 
 
 class ZoneTransferRequestAPIv2Adapter(base.APIv2Adapter):
@@ -68,9 +67,10 @@ class ZoneTransferRequestAPIv2Adapter(base.APIv2Adapter):
             object, *args, **kwargs)
 
         try:
-            target = {
-                'tenant_id': object.tenant_id,
-            }
+            if policy.enforce_new_defaults():
+                target = {constants.RBAC_PROJECT_ID: object.tenant_id}
+            else:
+                target = {'tenant_id': object.tenant_id}
 
             policy.check(
                 'get_zone_transfer_request_detailed',
@@ -85,7 +85,7 @@ class ZoneTransferRequestAPIv2Adapter(base.APIv2Adapter):
         return obj
 
     @classmethod
-    def _get_path(cls, request):
+    def _get_path(cls, request, *args):
         return '/v2/zones/tasks/transfer_requests'
 
 
