@@ -20,14 +20,14 @@ from oslo_log import log as logging
 from designate import exceptions
 from designate import storage
 from designate import objects
-from designate.central import service as central_service
-from designate.quota.base import Quota
+from designate.quota import base
+from designate.storage import transaction
 
 
 LOG = logging.getLogger(__name__)
 
 
-class StorageQuota(Quota):
+class StorageQuota(base.Quota):
     __plugin_name__ = 'storage'
 
     def __init__(self):
@@ -55,7 +55,7 @@ class StorageQuota(Quota):
 
         return {resource: quota['hard_limit']}
 
-    @central_service.transaction
+    @transaction
     def set_quota(self, context, tenant_id, resource, hard_limit):
         context = context.deepcopy()
         context.all_tenants = True
@@ -74,7 +74,7 @@ class StorageQuota(Quota):
         if resource not in list(six.iterkeys(
                self.get_default_quotas(context))):
             raise exceptions.QuotaResourceUnknown("%s is not a valid quota "
-                                                  "resource", resource)
+                                                  "resource" % resource)
 
         try:
             create_quota()
@@ -87,7 +87,7 @@ class StorageQuota(Quota):
 
         return {resource: hard_limit}
 
-    @central_service.transaction
+    @transaction
     def reset_quotas(self, context, tenant_id):
         context = context.deepcopy()
         context.all_tenants = True
