@@ -14,9 +14,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import time
-import hashlib
 
 from oslo_log import log as logging
+from oslo_utils.secretutils import md5
 from sqlalchemy import select, distinct, func
 from sqlalchemy.sql.expression import or_
 
@@ -799,11 +799,11 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
         """
         Calculates the hash of the record, used to ensure record uniqueness.
         """
-        md5 = hashlib.md5()
-        md5.update(("%s:%s" % (record.recordset_id,
-                               record.data)).encode('utf-8'))
+        md5sum = md5(usedforsecurity=False)
+        md5sum.update(("%s:%s" % (record.recordset_id,
+                                  record.data)).encode('utf-8'))
 
-        return md5.hexdigest()
+        return md5sum.hexdigest()
 
     def create_record(self, context, zone_id, recordset_id, record):
         # Fetch the zone as we need the tenant_id
@@ -1488,6 +1488,14 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
         ).select_from(ljoin)
 
         if not context.all_tenants:
+            # If we have a system scoped token with no project_id and
+            # all_tenants was not used, we don't know what records to return,
+            # so return an empty list.
+            if not context.project_id:
+                if one:
+                    return objects.ZoneTransferRequest()
+                return objects.ZoneTransferRequestList()
+
             query = query.where(or_(
                 table.c.tenant_id == context.project_id,
                 table.c.target_tenant_id == context.project_id))
@@ -1498,7 +1506,8 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
             exceptions.ZoneTransferRequestNotFound,
             criterion,
             one=one, marker=marker, limit=limit, sort_dir=sort_dir,
-            sort_key=sort_key, query=query, apply_tenant_criteria=False
+            sort_key=sort_key, query=query,
+            apply_tenant_criteria=False
         )
 
     def create_zone_transfer_request(self, context, zone_transfer_request):
@@ -1798,5 +1807,5 @@ class SQLAlchemyStorage(sqlalchemy_base.SQLAlchemy, storage_base.Storage):
     def _rname_check(self, criterion):
         # If the criterion has 'name' in it, switch it out for reverse_name
         if criterion is not None and criterion.get('name', "").startswith('*'):
-                criterion['reverse_name'] = criterion.pop('name')[::-1]
+            criterion['reverse_name'] = criterion.pop('name')[::-1]
         return criterion
