@@ -13,8 +13,8 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import six
-from mock import patch
+from unittest.mock import patch
+
 import oslo_messaging as messaging
 from oslo_log import log as logging
 
@@ -347,7 +347,7 @@ class ApiV2RecordSetsTest(ApiV2TestCase):
         correct_results = [1, 1, 2, 1, 1, 2, 1, 1]
 
         for get_url, correct_result in \
-                six.moves.zip(get_urls, correct_results):
+                zip(get_urls, correct_results):
 
             response = self.client.get(get_url)
 
@@ -567,6 +567,17 @@ class ApiV2RecordSetsTest(ApiV2TestCase):
         self._assert_exception('invalid_object', 400,
                                self.client.put_json, url, body)
 
+    def test_create_txt_record_multiple_strings(self):
+        # create TXT record with string split in 2
+        new_zone = self.create_zone(name='example.net.')
+        recordset = self.create_recordset(new_zone, 'TXT')
+        self.create_record(new_zone, recordset)
+        record = '"{}" "{}"'.format('a' * 250, 'a' * 250)
+        body = {'description': 'Tester', 'records': [record]}
+        url = '/zones/%s/recordsets/%s' % (recordset['zone_id'],
+                                           recordset['id'])
+        self.client.put_json(url, body, status=202)
+
     def test_update_recordset_with_record_clear(self):
         # Create a recordset with one record
         recordset = self.create_recordset(self.zone, 'A')
